 *==================== PROGRAM: PSI_ALL_CONTROL.SAS ======================= ;
 * ------------------------------------------------------------------------ ;
 *                    >>>  AHRQ QI ICD-09 VERSION 6.0.2 <<<
 *                      >>> VERSION DATE JULY 2017 <<<
 * ------------------------------------------------------------------------ ;
 * The Patient Safety Indicator (PSI) module of the AHRQ Quality
   Indicators software includes the following programs:
   
    1. PSI_ALL_CONTROL.sas   Assigns user inputs required by other programs
                            and optional output options.  
                        
    2. PSI_ALL_FORMATS.sas   Creates SAS format library used by other programs.

    3. PSI_ALL_MEASURES.sas  Assigns numerator, denominator, and comorbidity flags
                            for Patient Safety Indicators.

    4. PSI_AREA_OBSERVED.sas Calculates observed rates for area level indicators.

    5. PSI_PROV_OBSERVED.sas Calculates observed rates for provider level indicators.

    6. PSI_PROV_RISKADJ.sas Calculates risk adjusted rates for provider level indicators.

    7. PSI_PROV_COMPOSITE.sas Calculates a composite rate from provider level indicators.


 * The software also requires the following files:
 
    1. Discharges.sas7bdat  User supplied discharge level file organized according 
                            to the layout in the software instructions.
                            The file name is up to the user but must be listed below.
                            
    2. PSI_Dx_Px_Macros.sas Standard processes used by the other SAS programs.
                            The user does not need to open.
                            
    3. pop95t15.txt         Population file with counts by area, age, and sex.
                            Required for area rate calculation.    

    4. PSI_COMORB_FORMAT_V09.sas Creates formats to map diagnosis codes to comorbidity 
                            for use by the Elixhauser Comorbidity software.

    5. PSI_COMORB_CODE_V09.sas  Elixhauser Comorbidity software assigns variables   
                            identifying comorbidities in hospital discharges.

*   See the PSI_V6_ICD9_Release_Notes.txt file for version change details.

***************************************************************************** ;
******************************* PLEASE READ ********************************* ;
***************************************************************************** ;
 * The AHRQ Quality Indicator software is intended for use with discharges
   coded according to the standards in place at the date of the discharge. 
   Discharges should be classified under the ICD-09-CM/PCS specifications 
   effective 10/1/2007 to 09/30/2015. All diagnosis codes require a corresponding 
   Present On Admission, POA, value coded according to UB04 standards. 
   
 * The USER MUST modify portions of the following code in order to
   run this software.  With one exception (see NOTE immediately
   following this paragraph), the only changes necessary to run
   this software are changes in this program (PSI_ALL_CONTROL.SAS). 
   The modifications include such items as specifying the name and location
   of the input data set, the year of population data to be used, and the 
   name and location of output data sets.
 
 * NOTE:  PSI_ALL_CONTROL.SAS provides the option to read data in and write 
          data out to different locations.  For example, "libname INMSR" points
          to the location of the input data set for the PSI_ALL_MEASURES.SAS program
          and "libname OUTMSR" points to the location of the output data set
          created by the PSI_ALL_MEASURES.SAS program.  The location and file name of 
          each input and output can be assigned separately below. The default 
          values will place output in a SASData folder with standard names for
          each file based on the location of the PSI folder listed in the 
          PATHNAME variable.
          
 * NOTE:  In the other programs included with this package there is a 
          line of code that begins with "filename CONTROL".  
          The USER MUST include after "filename CONTROL" the location
          of the PSI_ALL_CONTROL.SAS file.

 Generally speaking, a first-time user of this software would proceed 
 as outlined below:

    1. Modify and save PSI_ALL_CONTROL.SAS (This program. - MUST be done.)
    2. Open PSI_ALL_FORMATS.SAS and specify location (path name) of
       PSI_ALL_CONTROL.SAS. (MUST be done.)
    3. Run PSI_ALL_FORMATS.SAS.  (MUST be done.) 
    4. Open PSI_ALL_MEASURES.SAS and specify location of PSI_ALL_CONTROL.SAS
       program.  (MUST be done.)
    5. Run PSI_ALL_MEASURES.SAS.  (MUST be done.)
    6. To calculate provider level rates for Patient Safety Indicators:
         a. Open PSI_PROV_OBSERVED.SAS and specify location
            of PSI_ALL_CONTROL.SAS program. (MUST be done.) 
         b. Run PSI_PROV_OBSERVED.SAS. (MUST have run PSI_ALL_MEASURES.SAS.)
         c. Run PSI_PROV_RISKADJ.SAS.  (MUST have run PSI_PROV_OBSERVED.SAS.)
         d. Run PSI_PROV_COMPOSITE.SAS (MUST have run PSI_PROV_RISKADJ.SAS.)
    7. To calculate area level rates for Patient Safety Indicators:
         a.  Open PSI_AREA_OBSERVED.SAS and specify location
             of PSI_ALL_CONTROL.SAS program.  (MUST be done.) 
         b.  Run PSI_AREA_OBSERVED.SAS.  (MUST have run PSI_ALL_MEASURES.SAS.)

 * ----------------------------------------------------------------- ;
 * ---                       All Programs                        --- ;
 * ----------------------------------------------------------------- ;
*PATHNAME specifies the location of the PSI folder which includes the
          Programs, Macros, and SASdata subfolders;
%LET PATHNAME=c:\pathname\PSI;                     *<===USER MUST modify;
*DISFOLDER specifies the folder that contains the discharge data;
%LET DISFOLDER=c:\pathname;                    *<===USER MUST modify;
*DISCHARGE specifies the name of the discharge data file;
%LET DISCHARGE=discharges;                      *<===USER MUST modify;
*SUFX specifies an identifier suffix to be placed on output datasets;
%LET SUFX = v6_ICD09;                           *<===USER may modify;
*LIBRARY is where formats generated by PSI_ALL_FORMATS will be saved.;    
LIBNAME LIBRARY  "&PATHNAME.\SASData";              *<===USER may modify;
 * ---------------------------------------------------------------- ;
 * --- INDICATE IF COUNTY-LEVEL AREAS SHOULD BE CONVERTED TO MAs -- ;
 * ---     0 - County level with U.S. Census FIPS                -- ;
 * ---     1 - County level with Modified FIPS                   -- ;
 * ---     2 - Metro Area level with OMB 1999 definition         -- ;
 * ---     3 - Metro Area level with OMB 2003 definition         -- ;
 * ---------------------------------------------------------------- ;
%LET MALEVL = 0;                                 *<===USER may modify;
 * ---------------------------------------------------------------- ;
 * NOTE:  SELECT THE POPULATION DATA FOR THE YEAR THAT BEST MATCHES ;
 *        THE DISCHARGE DATA. POPYEAR WILL IDENTIFY POPULATION USED ;
 *        BY THE PSI_AREA_OBSERVED AND RISKADJ PROGRAMS             ;
 *        DATA ARE AVAILABLE FOR 1995 TO 2015.                      ;
 * ---------------------------------------------------------------- ;
%LET POPYEAR = 2015;                             *<===USER may modify;
 * ---------------------------------------------------------------- ;
 * --- SET LOCATION OF POPULATION FILE                          --- ;
 * ---------------------------------------------------------------- ;
filename POPFILE  "&PATHNAME.\Parmfiles\pop95t15.txt";     *<===USER may modify;
 * ---------------------------------------------------------------- ;
 * --- INDICATE IF RECORDS SHOULD BE PRINTED IN SAS OUTPUT AT   --- ;
 * --- END OF EACH PROGRAM.  0 = NO, 1 = YES                    --- ;
 * ---------------------------------------------------------------- ;
%LET PRINT = 0;                                 *<===USER may modify.;
 * ---------------------------------------------------------------- ;
 * --- COMMENT OUT TO CREATE AN UNCOMPRESSED FILE               --- ;
 * ---------------------------------------------------------------- ;
Options Compress=YES;                           *<===USER may modify.;
 * ---------------------------------------------------------------- ;
 * --- SET LOCATION OF SAS MACRO LIBRARY                        --- ;
 * ---------------------------------------------------------------- ;
filename MacLib "&PATHNAME.\Macros\";       *<===USER may modify.;
 * ---------------------------------------------------------------- ;
 * ---              Program : PSI_ALL_MEASURES                  --- ;
 * ---------------------------------------------------------------- ;
 * ---------------------------------------------------------------- ;
 * --- SET LOCATION OF PSI_ALL_MEASURES INPUT DATA              --- ;
 * ---------------------------------------------------------------- ;
libname INMSR  "&DISFOLDER.";                     *<==USER may modify;
 * ---------------------------------------------------------------- ;
 * --- SET LOCATION OF PSI_ALL_MEASURES OUTPUT DATA             --- ;
 * ---------------------------------------------------------------- ;
libname OUTMSR "&PATHNAME.\SASdata";          *<==USER may modify;
 * --- SET NAME OF OUTPUT FILE FROM PSI_ALL_MEASURES.SAS        --- ;    
%LET OUTFILE_MEAS = PSMSR_&SUFX;                 *<===USER may modify;
 * ---------------------------------------------------------------- ;
 * --- MODIFY INPUT AND OUTPUT FILE                             --- ;
 * ---------------------------------------------------------------- ;
 * --- PROGRAM DEFAULT ASSUMES THERE ARE                        --- ;
 * ---     35 DIAGNOSES (DX1-DX35)                              --- ;
 * ---     30 PROCEDURES (PR1-PR30)                             --- ;
 * ---------------------------------------------------------------- ;
 * --- MODIFY NUMBER OF DIAGNOSIS AND PROCEDURE VARIABLES TO    --- ;
 * --- MATCH USER DISCHARGE INPUT DATA                          --- ;
 * ---------------------------------------------------------------- ;
%LET NDX = 35;                                    *<===USER may modify;
%LET NPR = 30;                                    *<===USER may modify;
 * ---------------------------------------------------------------- ;
 * - INDICATE IF DATA AVAILABLE REGARDING NUMBER OF DAYS        --- ;
 * - FROM ADMISSION TO SECONDARY PROCEDURES                     --- ;
 * - 0 = PRDAY IS NOT INCLUDED, 1 = PRDAY IS INCLUDED           --- ;
 * ---------------------------------------------------------------- ;
%LET PRDAY  = 1;                                  *<===USER may modify; 

* ----------------------------------------------------------------- ;
 * - CREATE PERMANENT SAS DATASET TO STORE RECORDS THAT WILL    --- ;
 * - NOT BE INCLUDED IN CALCULATIONS BECAUSE KEY VARIABLE       --- ;
 * - VALUES ARE MISSING.  THIS DATASET SHOULD BE REVIEWED AFTER --- ;
 * - RUNNING PSI_ALL_MEASURES.                                  --- ;
 * ---------------------------------------------------------------- ;
%LET DELFILE  = PSI_DELETED_&SUFX.;               *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * ---------------------------------------------------------------- ;
 * ---               Program: PSI_PROV_OBSERVED.SAS             --- ;
 * ---------------------------------------------------------------- ;
 * --- SET LOCATION OF PROVIDER OBSERVERED OUTPUT LIBRARY.      --- ;
 * ---------------------------------------------------------------- ;
libname OUTPOBS "&PATHNAME.\SASdata";         *<===USER may modify;

  * ------------------------------------------------------------------------- ;
 * --- TYPELVLP indicates the levels (or _TYPE_) of                      --- ;
 * --- summarization to be kept in the output.                           --- ;
 * ---                                                                   --- ;
 * ---  TYPELVLP      Stratification                       GEE Model     --- ;
 * ---  --------  ------------------------------------  --------------   --- ;
 * ---     0      overall                                  AGE_SEX       --- ;
 * ---     1                                      race     AGE_SEX       --- ;
 * ---     2                              payer            AGE_SEX       --- ;
 * ---     3                              payer * race     AGE_SEX       --- ;
 * ---     4                        sex                    NO_SEX        --- ;
 * ---     5                        sex         * race     NO_SEX        --- ;
 * ---     6                        sex * payer            NO_SEX        --- ;
 * ---     7                        sex * payer * race     NO_SEX        --- ;
 * ---     8                  age                          NO_AGE        --- ;
 * ---     9                  age               * race     NO_AGE        --- ;
 * ---    10                  age       * payer            NO_AGE        --- ;
 * ---    11                  age       * payer * race     NO_AGE        --- ;
 * ---    12                  age * sex                    NO_AGE_SEX    --- ;
 * ---    13                  age * sex         * race     NO_AGE_SEX    --- ;
 * ---    14                  age * sex * payer            NO_AGE_SEX    --- ;
 * ---    15                  age * sex * payer * race     NO_AGE_SEX    --- ;
 * ---    16       provider                                AGE_SEX       --- ;
 * ---    17       provider                     * race     AGE_SEX       --- ;
 * ---    18       provider             * payer            AGE_SEX       --- ;
 * ---    19       provider             * payer * race     AGE_SEX       --- ;
 * ---    20       provider       * sex                    NO_SEX        --- ;
 * ---    21       provider       * sex         * race     NO_SEX        --- ;
 * ---    22       provider       * sex * payer            NO_SEX        --- ;
 * ---    23       provider       * sex * payer * race     NO_SEX        --- ;
 * ---    24       provider * age                          NO_AGE        --- ;
 * ---    25       provider * age               * race     NO_AGE        --- ;
 * ---    26       provider * age       * payer            NO_AGE        --- ;
 * ---    27       provider * age       * payer * race     NO_AGE        --- ;
 * ---    28       provider * age * sex                    NO_AGE_SEX    --- ;
 * ---    29       provider * age * sex         * race     NO_AGE_SEX    --- ;
 * ---    30       provider * age * sex * payer            NO_AGE_SEX    --- ;
 * ---    31       provider * age * sex * payer * race     NO_AGE_SEX    --- ;
 * ---                                                                   --- ;
 * --- The default TYPELVLP (0,16) will provide an overall               --- :
 * --- and provider-level totals. If you run stratifications that        --- ;
 * --- include Age and/or Sex, be aware that the numerical               --- ;
 * --- results for non-Age/Sex categories will be incorrect.             --- ;
 * ------------------------------------------------------------------------- ;
%LET  TYPELVLP = IN (0,16);                      *<===USER may modify;

* ------------------------------------------------------------------ ;
 * --- NAME OF SAS DATASET OUTPUT FROM PSI_PROV_OBSERVED         --- ;
 * --- SUMMARY OUTPUT FILE OF OBSERVED PROVIDER RATES.           --- ;
 * ----------------------------------------------------------------- ;
%LET  OUTFILE_PROVOBS = PSPOBS_&SUFX.;             *<===USER may modify;

 * ----------------------------------------------------------------- ;
 * --- INDICATE IF A COMMA-DELIMITED FILE SHOULD BE GENERATED FOR--- ;
 * --- EXPORT INTO A SPREADSHEET. 0 = NO, 1 = YES.               --- ;
 * ----------------------------------------------------------------- ;
%LET TXTPOBS=0;                                   *<===USER may modify;

 * ----------------------------------------------------------------- ;
 * --- IF YOU CREATE A COMMA-DELIMITED FILE, SPECIFY THE NAME AND -- ;
 * --- LOCATION OF THE FILE.                                     --- ;
 * ----------------------------------------------------------------- ;
filename PSTXTPOB "&PATHNAME.\SASdata\PSPOBS_&SUFX..TXT"; *<===USER may modify;

 * ----------------------------------------------------------------- ;
 * ---   Program: PSI_PROV_RISKADK - RISK-ADJUSTED RATES         --- ;
 * ----------------------------------------------------------------- ;
 * ----------------------------------------------------------------- ;
libname OUTPRISK "&PATHNAME.\SASData";               *<===USER MUST modify;

 * ----------------------------------------------------------------- ;
 * --- SET NAME OF RISK ADJUSTMENT PARAMETERS DIRECTORY           -- ;
 * --- Contains provider level covariate GEE parameter .csv files.-- ;
 * ----------------------------------------------------------------- ;
%LET  RADIR = &PATHNAME.\ParmFiles\PSI_Covariates_v60;  *<===USER MUST modify;

 * ---------------------------------------------------------------- ;
 * --- SET NAME OF PROVIDER LEVEL OUTPUT FILE                   --- ;
 * ---------------------------------------------------------------- ;
%LET  OUTFILE_PROVRISK = PSPRSKADJ_&SUFX.;                       *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * --- INDICATE IF YOU WANT TO CREATE A COMMA-DELIMITED FILE    --- ;
 * --- SET TXTPRISK=1 AND SPECIFY THE LOCATION.                 --- ;
 * ---------------------------------------------------------------- ;
%LET TXTPRISK=1;                                   *<===USER may modify;
filename PSTXTPRA "&PATHNAME.\SASData\PSPRSKADJ_&SUFX..TXT";       *<===USER may modify;
 * ---------------------------------------------------------------- ;
 * ---   Program: PSI_PROV_COMPOSITE                            --- ;
 * ---------------------------------------------------------------- ;
libname OUTPCOMP "&PATHNAME.\SASData";               *<===USER MUST modify;

 * ---------------------------------------------------------------- ;
 * --- SET NAME OF FILE CONTAINING COMPONENT MEASURE REFERENCE  --- ;
 * --- RATES AND STANDARD DEVIATION ARRAYS AND THE PROVIDER     --- ;
 * --- LEVEL COMPOSITE OUTPUT FILE.                             --- ;
 * ---------------------------------------------------------------- ;
%LET PSCOMPRR = PSI_PROV_COMPOSITE_ARRAYS_V60.sas;         *<===USER may modify;
%LET OUTFILE_COMP = PSCOMP_&SUFX.;                         *<===USER may modify;

 * =================================================================;
 * ============ AREA-LEVEL PATIENT SAFETY INDICATORS ===============;
 * =================================================================;

 * ---------------------------------------------------------------- ;
 * ---       Program: PSI_AREA_OBSERVED                         --- ;
 * ---------------------------------------------------------------- ;
libname OUTAOBS "&PATHNAME.\SASdata";

 * ---------------------------------------------------------------- ;
 * --- TYPELVLA indicates the levels (or _TYPES_) of            --- ;
 * --- summarization to be kept in the output.                  --- ;
 * ---                                                          --- ;
 * ---  TYPELVLA      Stratification                            --- ;

 * ---  --------  -------------------------                     --- ;
 * ---     0      overall                                       --- ;
 * ---     1                           race                     --- ;
 * ---     2                     sex                            --- ;
 * ---     3                     sex * race                     --- ;
 * ---     4               age                                  --- ;
 * ---     5               age *       race                     --- ;
 * ---     6               age * sex                            --- ;
 * ---     7               age * sex * race                     --- ;
 * ---     8       area                                         --- ;
 * ---     9       area  *             race                     --- ;
 * ---    10       area  *       sex                            --- ;
 * ---    11       area  *       sex * race                     --- ;
 * ---    12       area  * age                                  --- ;
 * ---    13       area  * age *       race                     --- ;
 * ---    14       area  * age * sex                            --- ;
 * ---    15       area  * age * sex * race                     --- ;
 * ---                                                          --- ;
 * --- The default TYPELVLA (0,8) will provide an overall       --- :
 * --- and area-level totals.                                   --- ;

 * ---------------------------------------------------------------- ;
%LET   TYPELVLA = IN (0,8);                     *<===USER may modify;

* ------------------------------------------------------------------ ;
 * --- NAME OF SAS DATASET OUTPUT FROM PROGRAM PSI_AREA_OBSERVED --- ;
 * --- SUMMARY OUTPUT FILE OF OBSERVED AREA RATES.               --- ;
 * ----------------------------------------------------------------- ;
%LET  OUTFILE_AREAOBS = PSAOBS_&SUFX;             *<===USER may modify;

 * ----------------------------------------------------------------- ;
 * --- INDICATE IF A COMMA-DELIMITED FILE SHOULD BE GENERATED FOR--- ;
 * --- EXPORT INTO A SPREADSHEET. 0 = NO, 1 = YES.               --- ;
 * ----------------------------------------------------------------- ;
%LET TXTAOBS=0;                                   *<===USER may modify;

 * ----------------------------------------------------------------- ;
 * --- IF YOU CREATE A COMMA-DELIMITED FILE, SPECIFY THE LOCATION -- ;
 * --- OF THE FILE.                                              --- ;
 * ----------------------------------------------------------------- ;
filename PSTXTAOB "&PATHNAME.\SASdata\PSAOBS_&SUFX..TXT";  *<===USER may modify;

************************* END USER INPUT ************************** ;
